@@ -156,6 +156,7 @@ def rollback():
     Untars most recent rollback archive and sets it running.
     """
     print "ROLLING BACK"
+    ROLLBACK_CAP = env.config.get('rollback_cap', DEFAULT_ROLLBACK_CAP)
     rollback_file = '%s/%s-rollback_1.tar.bz2' % (env.rollbackdir, env.site)
     if exists(rollback_file): 
         #unzip in a tmp dir
@@ -288,7 +289,7 @@ def push_code():
 def _upload_config_template(template, dest, context):
     #first try to load the template from the local cfg_templates dir.
     #if it's not there then try loading from pkg_resources
-    path = silk.lib.get_template_path(template)
+    path = silk.lib.get_template_path(template, env.local_root)
     upload_template(path, dest, context=context, use_sudo=True)
 
 def _get_nginx_static_snippet(url_path, local_path):
