@@ -75,14 +75,14 @@ def get_config(site_root, role=None):
 
 def get_template_path(template, site_root=None):
     """
-    Returns path of template from site cfg_templates dir, if found there, else
-    returns template path from silk's cfg_templates dir.
+    Returns path of template from site conf_templates dir, if found there, else
+    returns template path from silk's conf_templates dir.
     """
     if site_root:
-        localpath=os.path.join(site_root, 'cfg_templates', template)
+        localpath=os.path.join(site_root, 'conf_templates', template)
         if os.path.isfile(localpath):
             return localpath
-    pkgpath=pkg_resources.resource_filename('silk', 'cfg_templates/%s' % template)
+    pkgpath=pkg_resources.resource_filename('silk', 'conf_templates/%s' % template)
     if os.path.isfile(pkgpath):
         return pkgpath
     else:
